@@ -83,11 +83,12 @@ import_copypaste_server <- function(id,
                                     btn_show_data = TRUE,
                                     show_data_in = c("popup", "modal"),
                                     trigger_return = c("button", "change"),
-                                    return_class = c("data.frame", "data.table", "tbl_df"),
+                                    return_class = c("data.frame", "data.table", "tbl_df", "raw"),
                                     reset = reactive(NULL),
                                     fread_args = list()) {
 
   trigger_return <- match.arg(trigger_return)
+  return_class <- match.arg(return_class)
 
   module <- function(input, output, session) {
 
